@@ -11,21 +11,24 @@ class TCPClient(object):
     def __init__(self, host=SERVER_DEFAULT, port=PORT_DEFAULT):
         self.host = host
         self.port = to_int(port)
-        self.conn = ClientConnection(self.host, self.port)
+        self._conn = ClientConnection(self.host, self.port)
+
+    def connect(self):
+        self._conn.connect()
 
     def send(self, data):
-        self.conn.send(data)
+        self._conn.send(data)
 
     def recv(self):
-        return self.conn.read()
+        return self._conn.read()
 
-    def execute(self, cmd=None, **params):
-        if not cmd:
-            raise Exception("No command provided to execute function!")
+    def disconnect(self):
+        self._conn.finish()
 
+    def execute(self, cmd, **params):
         params['cmd'] = cmd
-        self.conn.connect()
+        self.connect()
         self.send(params)
         res = self.recv()
-        self.conn.finish()
+        self.disconnect()
         return res
